FileStorageImpl class

File storage implementation

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String filename) → bool
Delete a file, return true if the file exists.
exist(String filename) → bool
Check if a file exists.
getFileBinary(String filename) → Uint8List?
Get file binary data by filename, return null if not exist.
getFilePath(String filename) → String?
Get file path by filename, return null if not exist.
list() → Iterable<File>
List all files in the storage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
write(String filename, List<int> bytes) → String
Write binary data to file, return the path.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(String category) → Future<FileStorageImpl>
Create a file storage instance with specified category as root directory.